<?php
/*
Plugin Name:  Simple Running Log
Plugin URI:   http://wordpress.org/support/plugin/simple-running-log
Description:  Add a simple running log to your website and update it via the WordPress Dashboard
Version:      1.6
Author:       Kevin Marsden
Author URI:   http://wwww.kmarsden.com/
License:      GNU GPL2       
*/
/*
Copyright 2013  Kevin Marsden

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as 
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

//Create the "**_running" table in the WP database to store running log data

global $wpdb;
global $current_log_version;
global $log_db_version;
$current_log_version = get_option('log_db_version');
$log_db_version = '2.0';

function running_install () {
	global $wpdb;
	global $log_db_version;
	global $current_log_version;
	
	$running_table = $wpdb->prefix . 'running';
		

	if($wpdb->get_var("SHOW TABLES LIKE '$running_table'") != $running_table) {
		
	$sql = "CREATE TABLE " . $running_table . " (
		id MEDIUMINT(9) NOT NULL AUTO_INCREMENT,
		srl_year VARCHAR(4),
		srl_month VARCHAR(2),
		srl_day VARCHAR(2),
		srl_time VARCHAR(5),
		distance VARCHAR(5) NOT NULL,
		the_date DATE NOT NULL,
		UNIQUE KEY id (id)
		);";
	}
	
	require_once ABSPATH.'wp-admin/includes/upgrade.php';
	if (isset($sql)) {
	dbDelta($sql);
	}
	
	//Check if the table has been updated to the new column names.  If not, the names are updated
	$updated_columns = $wpdb->query("SHOW COLUMNS FROM " . $running_table . " LIKE 'srl_year'");
	if ((($current_log_version == "1.0") OR (empty($current_log_version))) AND ($updated_columns == FALSE)) {
		$sql3 = "ALTER TABLE " . $running_table . " CHANGE year srl_year VARCHAR(4)";
		$sql4 = "ALTER TABLE " . $running_table . " CHANGE month srl_month VARCHAR(2)";
		$sql5 = "ALTER TABLE " . $running_table . " CHANGE day srl_day VARCHAR(2)";
		$sql6 = "ALTER TABLE " . $running_table . " CHANGE time srl_time VARCHAR(5)";
		$wpdb->query($sql3);
		$wpdb->query($sql4);
		$wpdb->query($sql5);
		$wpdb->query($sql6);
	}
	
	//Check if this is an db upgrade.  If so, migrate old data to the new column
	if (($current_log_version == "1.0") || (empty($current_log_version))) {	
		$sql2 = "UPDATE " . $running_table . " SET the_date = CONCAT_WS('-', srl_year, srl_month, srl_day);";
		$wpdb->query($sql2);
	}
	
	//Update the db version in the options table
	if (isset($log_db_version)) {
	update_option('log_db_version', $log_db_version);
	}
}

//Registration hook to create the table when the plugin is activated

register_activation_hook(__FILE__,'running_install');


//Registers and enqueues admin-specific JavaScript and CSS
function register_admin_scripts() {
	wp_enqueue_script( 'jquery-ui-datepicker' );
	wp_enqueue_script( 'wp-jquery-date-picker', plugins_url( 'simple-running-log/js/admin.js' ) );
	wp_enqueue_style( 'jquery-ui-datepicker', 'http://ajax.googleapis.com/ajax/libs/jqueryui/1.8.18/themes/smoothness/jquery-ui.css' );
} // end register_admin_scripts

//Enqueue jquery UI and CSS
add_action( 'admin_enqueue_scripts', 'register_admin_scripts' );


// Create the function to output the admin dashboard widget for user to enter log data

function running_widget_function() {

//Display Running Log Input Form
	echo '<form method="POST" action="" >';
	wp_nonce_field('running-log-input');
	echo '<table> 
		
		<tr>
		<td>Date:</td>
		<td><input id="datepicker" type="text" name="the_date" value="Select a date"></td>
		</tr>
		
		<tr>
		<td>Distance:</td>
		<td><input type="text" name="distancedata"></td>
		</tr> 
		
		<tr> 
		<td><input type="submit" value="Submit" name="Submit"></td>
		<td><input type="reset" value="Reset" name="Reset"></td>  
		</tr> 

	</table> 
	</form>';


//Submits data to the MYSQL database table **_running

	if (isset($_POST['Submit'])) {
		check_admin_referer('running-log-input');  //check nonces
		global $wpdb;
		$srl_table = $wpdb->prefix . "running"; 
		$distance = mysql_real_escape_string($_POST['distancedata']); 
		$the_date = mysql_real_escape_string($_POST['the_date']);
		$sql = "INSERT INTO " . $srl_table . "  (the_date,distance) VALUES ('$the_date', '$distance')"; 
	
		if ($wpdb->query($sql) === FALSE) {
			echo "There was an error adding your mileage";
		} 
		else {
			echo "Your entry was added to the running log";
		}	
	}
}

// Create the widget action hook function which activates the admin dashboard widget

function add_running_widgets() {
	wp_add_dashboard_widget('running_widget', 'Training Log Mileage', 'running_widget_function');
	
} 

// Hook into the 'wp_dashboard_setup' action to register our other functions

add_action('wp_dashboard_setup', 'add_running_widgets' );

//Create Sidebar Widget

function running_widget_init() {

	function running_widget( $args ){
		extract($args);
		global $wpdb;	
		$m = date('m');
		$y = date('Y');
		$srl_table = $wpdb->prefix . "running";
		
		$wptime = current_time('mysql');
		$unixtime = strtotime($wptime);
		$offset = date('w', $unixtime); //get day of week
		$offsetunix = $offset * 86400; //convert offset to seconds
		$wpstartwk = get_option('start_of_week'); //get the WordPress start of week setting
		$wpstartwkunix = $wpstartwk * 86400;  //convert setting to seconds
		if ($offset >= $wpstartwk ) {
			$week_begin = $unixtime - $offsetunix + $wpstartwkunix;
			}	
		else {
			$week_begin = $unixtime - $offsetunix - (7*86400) + $wpstartwkunix;
			}
		$begin_week_date = date('Y-m-d', $week_begin);  //Change to the needed date format	
	

		$rowa = $wpdb->get_var("SELECT SUM(distance) FROM " . $srl_table . " WHERE the_date > CAST('$begin_week_date' as DATE)");
		$row1 = $wpdb->get_var("SELECT SUM(distance) FROM " . $srl_table . " WHERE month(the_date) = '$m' and year(the_date) = '$y'");
		$row2 = $wpdb->get_var("SELECT SUM(distance) FROM " . $srl_table . " WHERE year(the_date) = '$y'");
		$row3 = $wpdb->get_var("SELECT SUM(distance) FROM " . $srl_table);
		$formateda=number_format($rowa);
		$formated1=number_format($row1);
		$formated2=number_format($row2);
		$formated3=number_format($row3);

		// Set Sidebar Widget Name 
		$title = 'Training Log Mileage';
		
		//Before Widget (defined by theme) 
		echo $before_widget;

		echo $before_title . $title . $after_title;
		echo "<table style='border-spacing:5px 3px; border-collapse: separate;'>"
		. "<tr><td>This Week:</td> "
		. "<td  style='text-align:right;'>"
		. $formateda
		. "</td></tr>"
		. "<tr><td>This Month:</td>"
		. "<td  style='text-align:right;'>"
		. $formated1
		. "</td></tr>"
		. "<tr><td>This Year:</td>"
		. "<td  style='text-align:right;'>"
		.  $formated2
		. "</td></tr>"
		. "<tr><td>Total Mileage:</td>"
		. "<td  style='text-align:right;'>"
		. $formated3
		. "</td></tr>"
		. "</table>";
		
		// After Widget (defined by theme)
		echo $after_widget;
		}

	wp_register_sidebar_widget('running_widget','Training Log', 'running_widget');

}

add_action('plugins_loaded', 'running_widget_init');